@@ -14,7 +14,8 @@ Email: matt.c.jones.aoe@gmail.com
 
 from numpy import atleast_1d, ones, sqrt, shape
 
-from flightcondition.atmosphere import Atmosphere, DimensionalData
+from flightcondition.atmosphere import Atmosphere, AccessByName,\
+    DimensionalData
 from flightcondition.constants import PhysicalConstants as Phys
 from flightcondition.units import unit, dimless, check_area_dimensioned,\
     check_dimensioned, check_length_dimensioned, check_US_length_units,\
@@ -56,20 +57,20 @@ class Airspeed(DimensionalData):
         """
         pp_ = '~P' if pretty_print else ''
 
-        M_str = f"M      = {self.M:10.5g{pp_}}"
+        M_str = f"M       = {self.M:10.5g{pp_}}"
 
         if US_units:
-            TAS_str = f"TAS    = {self.TAS.to('knots'):10.5g{pp_}}"
-            CAS_str = f"CAS    = {self.CAS.to('knots'):10.5g{pp_}}"
-            EAS_str = f"EAS    = {self.EAS.to('knots'):10.5g{pp_}}"
-            q_str   = f"q_inf  = {self.q_inf.to('lbf/ft^2'):10.5g{pp_}}"
-            Re_by_L_str = f"Re/L = {self.Re_by_L.to('1/in'):10.5g~P}"
+            TAS_str = f"TAS     = {self.TAS.to('knots'):10.5g{pp_}}"
+            CAS_str = f"CAS     = {self.CAS.to('knots'):10.5g{pp_}}"
+            EAS_str = f"EAS     = {self.EAS.to('knots'):10.5g{pp_}}"
+            q_str   = f"q_inf   = {self.q_inf.to('lbf/ft^2'):10.5g{pp_}}"
+            Re_by_L_str = f"Re_by_L = {self.Re_by_L.to('1/in'):10.5g~P}"
         else:  # SI units
-            TAS_str = f"TAS    = {self.TAS.to('m/s'):10.5g{pp_}}"
-            CAS_str = f"CAS    = {self.CAS.to('m/s'):10.5g{pp_}}"
-            EAS_str = f"EAS    = {self.EAS.to('m/s'):10.5g{pp_}}"
-            q_str   = f"q_inf  = {self.q_inf.to('Pa'):10.5g{pp_}}"
-            Re_by_L_str = f"Re/L = {self.Re_by_L.to('1/mm'):10.5g~P}"
+            TAS_str = f"TAS     = {self.TAS.to('m/s'):10.5g{pp_}}"
+            CAS_str = f"CAS     = {self.CAS.to('m/s'):10.5g{pp_}}"
+            EAS_str = f"EAS     = {self.EAS.to('m/s'):10.5g{pp_}}"
+            q_str   = f"q_inf   = {self.q_inf.to('Pa'):10.5g{pp_}}"
+            Re_by_L_str = f"Re_by_L = {self.Re_by_L.to('1/mm'):10.5g~P}"
 
         # Insert longer variable name into output
         max_var_chars = max([
@@ -118,11 +119,11 @@ class Length(DimensionalData):
             str: String representation
         """
 
-        Re_str = f"Re     = {self.Re:10.5g~P}"
+        Re_str = f"Re      = {self.Re:10.5g~P}"
         if US_units:
-            L_str = f"L    = {self.L.to('ft'):10.5g~P}"
+            L_str = f"L       = {self.L.to('ft'):10.5g~P}"
         else:  # SI units
-            L_str = f"L    = {self.L.to('m'):10.5g~P}"
+            L_str = f"L       = {self.L.to('m'):10.5g~P}"
 
         # Insert longer variable name into output
         max_var_chars = max([
@@ -310,6 +311,24 @@ class FlightCondition(DimensionalData):
         self.byname._populate_data(varsobj=self.len,
                                    varnames_dict=self.len.varnames)
 
+        # Access all variables from .byvar. at base level
+        self.byvar = AccessByName()
+
+        byvar_atm = {}
+        for var, _ in self.atm.varnames.items():
+            byvar_atm[var] = var
+        self.byvar._populate_data(self.atm, byvar_atm)
+
+        byvar_vel = {}
+        for var, _ in self.vel.varnames.items():
+            byvar_vel[var] = var
+        self.byvar._populate_data(self.vel, byvar_vel)
+
+        byvar_len = {}
+        for var, _ in self.len.varnames.items():
+            byvar_len[var] = var
+        self.byvar._populate_data(self.len, byvar_len)
+
     @staticmethod
     def _isentropic_mach(p_0, p):
         """Isentropic flow equation for Mach number
